-- Dungeon Tactics
-- Copyright 2012 lukas w. irwin [ lukas.w.irwin@gmail.com ]
-- This program is free software under the terms of the GNU General Public License version 3 or later.
-- vendor.lua

vendor = state:new()

-- print "[vendor]"

-- creation
function vendor:new (o)
	-- print "[vendor] new vendor"
	o = o or {}
	setmetatable(o, self)
	self.__index = self
	self.sid = 0

	width = 250
	height = 290
	-- unit list table
	x = screen_width/2-200
	y = screen_height/2-140
	image_background_vendor = sim:addImage( 0, texture_background_512x512, xcore.x2dpoint(x, y),
		xcore.x2drect(0,0,64,64), xcore.xcolour(255,255,255,255) )	
	x = x + 4
	y = y + 4
	table_vendor_list = sim:addTable( 1299, true, xcore.x2drect( x+0, y+0, x+width, y+height ) )
	table_vendor_list:addColumn( "Item       ", 1 )
	table_vendor_list:addColumn( "Value", 2 )

	
	btn_w = 128
	btn_h = 30
	-- add some buttons
	x = screen_width/2+80
	y = screen_height/2-140
	button_vendor_sell = sim:addButton( 781, xcore.x2drect( x, y, x+btn_w, y+btn_h ), "Sell" )
	button_vendor_sell:setVisible( false )
	button_vendor_sell:setImage( button_texture )
	button_vendor_sell:setPressedImage( button_pressed_texture )

	y = y + btn_h + 20
	button_vendor_buy = sim:addButton( 782, xcore.x2drect( x, y, x+btn_w, y+btn_h ), "Buy" )
	button_vendor_buy:setVisible( false )
	button_vendor_buy:setImage( button_texture )
	button_vendor_buy:setPressedImage( button_pressed_texture )

	sim:bindGUI ( "button_vendor_sell_pressed", 781, xcore.XGUI_BUTTON_CLICKED )
	sim:bindGUI ( "button_vendor_buy_pressed", 782, xcore.XGUI_BUTTON_CLICKED )

	self.state = 1 -- 1 show sell list, 2 show buy list

	self:hide()
	return o
end

function vendor:show()
	-- print "[vendor] show"

	text_title:setVisible( true )
	text_title:setText( "Vendor" )
	image_background_title:setVisible( true )
	button_vendor_sell:setVisible( true )
	button_vendor_buy:setVisible( true )
	table_vendor_list:setVisible( true )
	image_background_vendor:setVisible( true )

	self:update()
end

function vendor:hide()
	-- print "[vendor] hide"
	image_background_title:setVisible( false )
	button_vendor_sell:setVisible( false )
	button_vendor_buy:setVisible( false )
	table_vendor_list:setVisible( false )
	image_background_vendor:setVisible( false )

end

function vendor:update()
	-- print("[vendor] update")
	table_vendor_list:clear()
	table_vendor_list:addColumn( "Item              ", 1 )
	table_vendor_list:addColumn( "Value", 2 )
	
	if self.state == 1 then
		-- sell items
		text_title:setText( "Inventory" )
		statement =             " SELECT inventory_item_id, inventory_user_id, inventory_storage, item_name, item_value "
		statement = statement .." FROM table_inventory "
		statement = statement .." LEFT JOIN table_items ON inventory_item_id = item_id"
		statement = statement .." WHERE inventory_user_id = 1 AND inventory_storage = 0"
	else
		-- buy items
		text_title:setText( "Vendor Items" )
		statement =             " SELECT item_id, item_class, item_type, item_name, item_value "
		statement = statement .." FROM table_items "
		statement = statement .." WHERE ( item_type = 1 or item_type = 2 or item_type = 4 ) AND item_rarity <= " .. local_user.sequence
		statement = statement .." ORDER BY item_type ASC, item_name ASC "
	end

	-- print( statement )
	local q = sql:exe( statement )
	if q ~= nil then
		-- print ("returned " .. q:getRowCount() .. " rows ")		
		for i = 0, q:getRowCount()-1 do
			local n = i*q:getHeadCount()
			table_vendor_list:addRow( n )
			table_vendor_list:setCellText ( i, 0, q:getData( n+3 ) )
			
			
			if self.state == 1 then
				table_vendor_list:setCellText ( i, 1, math.floor(tonumber( q:getData( n+4 ))/4) .. "G" )
			else
				table_vendor_list:setCellText ( i, 1, q:getData( n+4 ).. "G" )
			end
		end
	end
end

function vendor:buy()
	-- print("[vendor] buy")
	if self.state == 2 then
		-- buy items
		-- print("[vendor] do buy")
		if table_vendor_list:getSelected() ~= -1 then
			-- print("[vendor] buy item " .. table_vendor_list:getCellText( table_vendor_list:getSelected(), 0 ) )
			-- get item frm database
			statement =             " SELECT item_id, item_value "
			statement = statement .." FROM table_items "
			statement = statement .." WHERE item_name = '" .. table_vendor_list:getCellText( table_vendor_list:getSelected(), 0 ) .. "'"
			-- print( statement )
			local q = sql:exe( statement )
			if q ~= nil then
				-- print ("returned " .. q:getRowCount() .. " rows ")		
				for i = 0, q:getRowCount()-1 do
					local n = i*q:getHeadCount()
					 id = tonumber( q:getData( n+0 ) )
					 val = tonumber( q:getData( n+1 ) )
				end
				
				-- check price of item against user's avaliable gold
				if val <= local_user.gold then
					-- give user the item
					statement = 			 " INSERT INTO table_inventory "
					statement = statement .. " ( inventory_item_id, inventory_user_id, inventory_storage ) "
					statement = statement .. " VALUES ( " .. id  .. ", 1, 0 )"
					sql:exe( statement )
					
					-- remove gold from user
					local_user.gold = local_user.gold - val
					local_user:save()
				else
					-- hmm...
					-- print("[vendor] you can not afford this item.")
				end
			end
		else
			-- print("[vendor] none selected")
		end
	else
		self.state = 2
	end	
	self:update()	
end

function vendor:sell()
	-- print("[vendor] sell")
	if self.state == 1 then
		-- sell items
		if table_vendor_list:getSelected() ~= -1 then
			-- print("sell item " .. table_vendor_list:getCellText( table_vendor_list:getSelected(), 0 ) )
			
			-- get item frm database
			statement =             " SELECT item_id, item_value, inventory_id "
			statement = statement .." FROM table_inventory "
			statement = statement .." LEFT JOIN table_items ON item_id = inventory_item_id "
			statement = statement .." WHERE item_name = '" .. table_vendor_list:getCellText( table_vendor_list:getSelected(), 0 ) .. "' "
			statement = statement .." LIMIT 1 "
			-- print( statement )
			local q = sql:exe( statement )
			if q ~= nil then
				-- print ("returned " .. q:getRowCount() .. " rows ")		
				for i = 0, q:getRowCount()-1 do
					local n = i*q:getHeadCount()
					 id = tonumber( q:getData( n+0 ) )
					 val = tonumber( q:getData( n+1 ) )
					 iid = tonumber( q:getData( n+2 ) )
				end
				-- print("id" .. id)
				-- print("iid" .. iid)
				-- inventory_item_id, inventory_user_id, inventory_storage
				statement = " DELETE FROM table_inventory WHERE inventory_id = " .. iid
				-- print( statement )
				sql:exe( statement )
				
				-- add val to user's goal.
				local_user.gold = local_user.gold + math.floor((val/4))
				local_user:save()
			end
		else
			-- print("none selected")
		end
	else
		self.state = 1
	end
	self:update()	
end

-- eof